==> jc-1.4.0.tar.gz: java/nio/charset/CoderResult__24Cache.h <==
// abstract class java.nio.charset.CoderResult$Cache

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 14254178dbad6381 java_nio_charset_CoderResult__24Cache

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_nio_charset_CoderResult__24Cache_H_
#define _JC_java_nio_charset_CoderResult__24Cache_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_nio_charset_CoderResult$object;
struct _jc_java_util_HashMap$object;

// Typedefs
typedef struct _jc_java_nio_charset_CoderResult__24Cache$sub_refs	_jc_java_nio_charset_CoderResult__24Cache$sub_refs;
typedef struct _jc_java_nio_charset_CoderResult__24Cache$sub_nonrefs	_jc_java_nio_charset_CoderResult__24Cache$sub_nonrefs;
typedef struct _jc_java_nio_charset_CoderResult__24Cache$refs	_jc_java_nio_charset_CoderResult__24Cache$refs;
typedef struct _jc_java_nio_charset_CoderResult__24Cache$nonrefs	_jc_java_nio_charset_CoderResult__24Cache$nonrefs;
typedef struct _jc_java_nio_charset_CoderResult__24Cache$object	_jc_java_nio_charset_CoderResult__24Cache$object;

typedef const struct _jc_java_nio_charset_CoderResult__24Cache$vmethods	_jc_java_nio_charset_CoderResult__24Cache$vmethods;
typedef const struct _jc_java_nio_charset_CoderResult__24Cache$vtable	_jc_java_nio_charset_CoderResult__24Cache$vtable;
typedef const struct _jc_java_nio_charset_CoderResult__24Cache$vtype	_jc_java_nio_charset_CoderResult__24Cache$vtype;

// Constructors
extern void _jc_java_nio_charset_CoderResult__24Cache$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_nio_charset_CoderResult__24Cache$object *);

// Virtual methods
extern struct _jc_java_nio_charset_CoderResult$object *_jc_java_nio_charset_CoderResult__24Cache$method$get$edc027d4a510997f(_jc_env *, struct _jc_java_nio_charset_CoderResult__24Cache$object *, jint);
extern struct _jc_java_nio_charset_CoderResult$object *_jc_java_nio_charset_CoderResult__24Cache$method$make$f3cbfffb1f7afd3c(_jc_env *, struct _jc_java_nio_charset_CoderResult__24Cache$object *, jint);

// Virtual method descriptors
extern _jc_method _jc_java_nio_charset_CoderResult__24Cache$method_info$get$edc027d4a510997f;
extern _jc_method _jc_java_nio_charset_CoderResult__24Cache$method_info$make$f3cbfffb1f7afd3c;

// Virtual methods structure
struct _jc_java_nio_charset_CoderResult__24Cache$vmethods {
	struct _jc_java_nio_charset_CoderResult$object	*(*get$edc027d4a510997f)(_jc_env *, struct _jc_java_nio_charset_CoderResult__24Cache$object *, jint);
	struct _jc_java_nio_charset_CoderResult$object	*(*make$f3cbfffb1f7afd3c)(_jc_env *, struct _jc_java_nio_charset_CoderResult__24Cache$object *, jint);
};

// Vtable
struct _jc_java_nio_charset_CoderResult__24Cache$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_nio_charset_CoderResult__24Cache$vmethods	java_nio_charset_CoderResult__24Cache;
};

// Vtype
struct _jc_java_nio_charset_CoderResult__24Cache$vtype {
	_jc_type			type;
	_jc_java_nio_charset_CoderResult__24Cache$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_nio_charset_CoderResult__24Cache$sub_refs {
	struct _jc_java_util_HashMap$object	*cache;
};

// Reference instance fields (object)
struct _jc_java_nio_charset_CoderResult__24Cache$refs {
    _jc_java_nio_charset_CoderResult__24Cache$sub_refs	java_nio_charset_CoderResult__24Cache;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_nio_charset_CoderResult__24Cache$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_nio_charset_CoderResult__24Cache$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_nio_charset_CoderResult__24Cache$sub_nonrefs	java_nio_charset_CoderResult__24Cache;
};

// Object instance structure
struct _jc_java_nio_charset_CoderResult__24Cache$object {
	_jc_java_nio_charset_CoderResult__24Cache$refs	refs[0];
	_jc_word		lockword;
	_jc_java_nio_charset_CoderResult__24Cache$vtype	*vtype;
	_jc_java_nio_charset_CoderResult__24Cache$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_nio_charset_CoderResult__24Cache$vtype _jc_java_nio_charset_CoderResult__24Cache$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_nio_charset_CoderResult__24Cache, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_nio_charset_CoderResult__24Cache$class_object;

#endif	/* _JC_java_nio_charset_CoderResult__24Cache_H_ */

==> jc-1.4.6.tar.gz: java/nio/charset/CoderResult__24Cache.h <==
// abstract class java.nio.charset.CoderResult$Cache

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 14254178dbad6381 java_nio_charset_CoderResult__24Cache

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_nio_charset_CoderResult__24Cache_H_
#define _JC_java_nio_charset_CoderResult__24Cache_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_nio_charset_CoderResult$object;
struct _jc_java_util_HashMap$object;

// Typedefs
typedef struct _jc_java_nio_charset_CoderResult__24Cache$sub_refs	_jc_java_nio_charset_CoderResult__24Cache$sub_refs;
typedef struct _jc_java_nio_charset_CoderResult__24Cache$sub_nonrefs	_jc_java_nio_charset_CoderResult__24Cache$sub_nonrefs;
typedef struct _jc_java_nio_charset_CoderResult__24Cache$refs	_jc_java_nio_charset_CoderResult__24Cache$refs;
typedef struct _jc_java_nio_charset_CoderResult__24Cache$nonrefs	_jc_java_nio_charset_CoderResult__24Cache$nonrefs;
typedef struct _jc_java_nio_charset_CoderResult__24Cache$object	_jc_java_nio_charset_CoderResult__24Cache$object;

typedef const struct _jc_java_nio_charset_CoderResult__24Cache$vmethods	_jc_java_nio_charset_CoderResult__24Cache$vmethods;
typedef const struct _jc_java_nio_charset_CoderResult__24Cache$vtable	_jc_java_nio_charset_CoderResult__24Cache$vtable;
typedef const struct _jc_java_nio_charset_CoderResult__24Cache$vtype	_jc_java_nio_charset_CoderResult__24Cache$vtype;

// Constructors
extern void _jc_java_nio_charset_CoderResult__24Cache$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_nio_charset_CoderResult__24Cache$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_nio_charset_CoderResult$object *_jc_java_nio_charset_CoderResult__24Cache$method$get$edc027d4a510997f(_jc_env *, struct _jc_java_nio_charset_CoderResult__24Cache$object *, jint) _JC_JCNI_ATTR;
extern struct _jc_java_nio_charset_CoderResult$object *_jc_java_nio_charset_CoderResult__24Cache$method$make$f3cbfffb1f7afd3c(_jc_env *, struct _jc_java_nio_charset_CoderResult__24Cache$object *, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_nio_charset_CoderResult__24Cache$method_info$get$edc027d4a510997f;
extern _jc_method _jc_java_nio_charset_CoderResult__24Cache$method_info$make$f3cbfffb1f7afd3c;

// Virtual methods structure
struct _jc_java_nio_charset_CoderResult__24Cache$vmethods {
	struct _jc_java_nio_charset_CoderResult$object	*(*get$edc027d4a510997f)(_jc_env *, struct _jc_java_nio_charset_CoderResult__24Cache$object *, jint) _JC_JCNI_ATTR;
	struct _jc_java_nio_charset_CoderResult$object	*(*make$f3cbfffb1f7afd3c)(_jc_env *, struct _jc_java_nio_charset_CoderResult__24Cache$object *, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_nio_charset_CoderResult__24Cache$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_nio_charset_CoderResult__24Cache$vmethods	java_nio_charset_CoderResult__24Cache;
};

// Vtype
struct _jc_java_nio_charset_CoderResult__24Cache$vtype {
	_jc_type			type;
	_jc_java_nio_charset_CoderResult__24Cache$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_nio_charset_CoderResult__24Cache$sub_refs {
	struct _jc_java_util_HashMap$object	*cache;
};

// Reference instance fields (object)
struct _jc_java_nio_charset_CoderResult__24Cache$refs {
    _jc_java_nio_charset_CoderResult__24Cache$sub_refs	java_nio_charset_CoderResult__24Cache;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_nio_charset_CoderResult__24Cache$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_nio_charset_CoderResult__24Cache$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_nio_charset_CoderResult__24Cache$sub_nonrefs	java_nio_charset_CoderResult__24Cache;
};

// Object instance structure
struct _jc_java_nio_charset_CoderResult__24Cache$object {
	_jc_java_nio_charset_CoderResult__24Cache$refs	refs[0];
	_jc_word		lockword;
	_jc_java_nio_charset_CoderResult__24Cache$vtype	*vtype;
	_jc_java_nio_charset_CoderResult__24Cache$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_nio_charset_CoderResult__24Cache$vtype _jc_java_nio_charset_CoderResult__24Cache$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_nio_charset_CoderResult__24Cache, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_nio_charset_CoderResult__24Cache$class_object;

#endif	/* _JC_java_nio_charset_CoderResult__24Cache_H_ */
